@@ -7,8 +7,15 @@
 # free software; you can redistribute it and/or modify it under the
 # same terms as Perl itself.
 #
-# $Revision: 1.16 $
+# $Revision: 1.18 $
 # $Log: WebFetch.pm,v $
+# Revision 1.18  1999/04/09 01:58:20  ikluft
+# added font_size/font_face, added references to WebFetch::CNNsearch
+# and WebFetch::COLA.
+#
+# Revision 1.17  1999/03/28 08:17:11  ikluft
+# add VERSION to WF export files, bump version to 0.04
+#
 # Revision 1.16  1999/03/22 06:26:15  ikluft
 # added MyNetscape export
 #
@@ -132,7 +139,7 @@ use Data::Dumper;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 @EXPORT = qw( );
-$VERSION = '0.03';
+$VERSION = '0.04';
 my $debug;
 
 # Preloaded methods go here.
@@ -276,6 +283,19 @@ I<url-prefix> line of the WebFetch::SiteNews news input file.
 If it is set in the WebFetch::SiteNews,
 it will override the --url_prefix command line parameter.
 
+=item --font_size I<number>
+
+(optional) choose a font size for generated HTML text.
+This will be used in a B<font> tag so it may be relative,
+like "-1" or "+1".
+
+=item --font_face I<string>
+
+(optional) choose a font face for generated HTML text.
+This will be used in a B<font> tag so it may be any standard font name
+or a list.  For example, for a sans-serif font, use
+"C<Helvetica,Arial,sans-serif>".
+
 =item --quiet
 
 (optional) suppress printed warnings for HTTP errors
@@ -306,7 +326,7 @@ sub run
 	my ( $caller_pkg, $caller_file, $caller_line ) = caller;
 	my ( $obj, $dir, $group, $mode, $export, $ns_export, $quiet,
 		$url_prefix, $ns_site_title, $ns_site_link, $ns_site_desc,
-		$ns_image_title, $ns_image_url );
+		$ns_image_title, $ns_image_url, $font_size, $font_face );
 
 
 	my $result = GetOptions (
@@ -321,6 +341,8 @@ sub run
 		"ns_image_title:s" => \$ns_image_title,
 		"ns_image_url:s" => \$ns_image_url,
 		"url_prefix:s" => \$url_prefix,
+		"font_size:s" => \$font_size,
+		"font_face:s" => \$font_face,
 		"quiet" => \$quiet,
 		"debug" => \$debug,
 		( eval "defined \@".$caller_pkg."::Options" )
@@ -354,6 +376,8 @@ sub run
 		(defined $ns_image_title) ? ( "ns_image_title" => $ns_image_title ) : (),
 		(defined $ns_image_url) ? ( "ns_image_url" => $ns_image_url ) : (),
 		(defined $url_prefix) ? ( "url_prefix" => $url_prefix ) : (),
+		(defined $font_size) ? ( "font_size" => $font_size ) : (),
+		(defined $font_face) ? ( "font_face" => $font_face ) : (),
 		(defined $quiet) ? ( "quiet" => $quiet ) : (),
 		)';
 	if ( $@ ) {
@@ -847,6 +871,7 @@ sub html_gen
 
         push @result, "<center>";
         push @result, "<table><tr><td>";
+	$self->font_start( \@result );
         if ( @$links >= 0 ) {
                 my $entry;
                 foreach $entry ( @$links ) {
@@ -859,8 +884,10 @@ sub html_gen
 				$link_count == int(($self->{num_links}+1)
 				/ $self->{table_sections}))
 			{
+				$self->font_end( \@result );
 				push @result, "</td>";
 				push @result, "<td width=45% valign=top>";
+				$self->font_start( \@result );
 			} else {
 				$style_para and push @result, "<p>";
 			}
@@ -870,12 +897,38 @@ sub html_gen
                         ."this information source.  "
                         ."Please check again later.)</i>";
         }
+	$self->font_end( \@result );
         push @result, "</td></tr></table>";
         push @result, "</center>";
  
 	$self->html_savable( $filename, join("\n",@result)."\n");
 }
 
+# internal-use function font_start, used by html_gen
+sub font_start
+{
+	my ( $self, $result ) = @_;
+
+	if (( defined $self->{font_size}) or ( defined $self->{font_face})) {
+		push @$result, "<font"
+			.(( defined $self->{font_size})
+				? " size=".$self->{font_size} : "" )
+			.(( defined $self->{font_face})
+				? " face=\"".$self->{font_face}."\"" : "" )
+			.">";
+	}
+}
+
+# internal-use function font_end, used by html_gen
+sub font_end
+{
+	my ( $self, $result ) = @_;
+
+	if (( defined $self->{font_size}) or ( defined $self->{font_face})) {
+		push @$result, "</font>";
+	}
+}
+
 =item $obj->html_savable( $filename, $content )
 
 This WebFetch utility function stores pre-generated HTML in a new entry in
@@ -898,12 +951,12 @@ sub html_savable
  
 	$self->raw_savable( $filename,
 		"<!--- begin text generated by "
-		."Perl5 WebFetch - do not manually edit --->\n"
+		."Perl5 WebFetch $VERSION - do not manually edit --->\n"
 		."<!--- WebFetch can be found at "
 		."http://www.svlug.org/sw/webfetch/ --->\n"
 		.$content
 		."<!--- end text generated by "
-		."Perl5 WebFetch - do not manually edit --->\n" );
+		."Perl5 WebFetch $VERSION - do not manually edit --->\n" );
 }
 
 =item $obj->raw_savable( $filename, $content )
@@ -1202,6 +1255,8 @@ http://www.svlug.org/sw/webfetch/
 
 =for html
 <a href="http://www.perl.org/">perl</a>(1),
+<a href="WebFetch::CNNsearch.html">WebFetch::CNNsearch</a>,
+<a href="WebFetch::COLA.html">WebFetch::COLA</a>,
 <a href="WebFetch::EGAuthors.html">WebFetch::EGAuthors</a>,
 <a href="WebFetch::Freshmeat.html">WebFetch::Freshmeat</a>,
 <a href="WebFetch::LinuxToday.html">WebFetch::LinuxToday</a>,
@@ -1211,13 +1266,13 @@ http://www.svlug.org/sw/webfetch/
 <a href="WebFetch::YahooBiz.html">WebFetch::YahooBiz</a>.
 
 =for text
-perl(1), WebFetch::EGAuthors, WebFetch::Freshmeat, WebFetch::LinuxToday,
-WebFetch::ListSubs, WebFetch::SiteNews, WebFetch::Slashdot,
-WebFetch::YahooBiz.
+perl(1), WebFetch::CNNsearch, WebFetch::COLA, WebFetch::EGAuthors,
+WebFetch::Freshmeat, WebFetch::LinuxToday, WebFetch::ListSubs,
+WebFetch::SiteNews, WebFetch::Slashdot, WebFetch::YahooBiz.
 
 =for man
-perl(1), WebFetch::EGAuthors, WebFetch::Freshmeat, WebFetch::LinuxToday,
-WebFetch::ListSubs, WebFetch::SiteNews, WebFetch::Slashdot,
-WebFetch::YahooBiz.
+perl(1), WebFetch::CNNsearch, WebFetch::COLA, WebFetch::EGAuthors,
+WebFetch::Freshmeat, WebFetch::LinuxToday, WebFetch::ListSubs,
+WebFetch::SiteNews, WebFetch::Slashdot, WebFetch::YahooBiz.
 
 =cut
